@@ -1,5 +1,6 @@
 import contextlib
 from abc import ABC, abstractmethod
+from pathlib import Path
 from typing import Iterator
 
 from ..datastreams import StreamEntry
@@ -8,12 +9,14 @@ from ..datastreams import StreamEntry
 class BaseReader(ABC):
     """Base reader."""
 
-    def __init__(self, log, *, source=None, **kwargs):
+    def __init__(self, *, source=None, base_path=None, **kwargs):
         """Constructor.
         :param source: Data source (e.g. filepath, stream, ...)
         """
-        self.source = source
-        self._log = log
+        if not source or hasattr(source, "read") or not base_path:
+            self.source = source
+        else:
+            self.source = Path(base_path).joinpath(source)
 
     @abstractmethod
     def __iter__(self) -> Iterator[StreamEntry]:
