@@ -13,3 +13,12 @@ def validate_date(date_format):
             ) from e
 
     return validate
+
+
+def validate_datetime(value):
+    try:
+        datetime.fromisoformat(value)
+    except Exception as e:
+        raise ValidationError(
+            f"Invalid datetime format, expecting iso format, got {value}"
+        ) from e
